==> trilinos-12.6.3-1-x86_64.pkg.tar.xz: usr/include/Zoltan2_config.h <==
/* define if we want to include experimental code */
/* #undef INCLUDE_ZOLTAN2_EXPERIMENTAL */

/* define if we want to include wolf experimental code */
/* #undef INCLUDE_ZOLTAN2_EXPERIMENTAL_WOLF */

/* define if we have MPI */
#define HAVE_ZOLTAN2_MPI

/* define if we want to use OpenMP */
#define HAVE_ZOLTAN2_OMP

/* define if we have the METIS library*/
/* #undef HAVE_ZOLTAN2_METIS */

/* define if we have the PaToH library*/
/* #undef HAVE_ZOLTAN2_PATOH */

/* define if we have the Scotch library*/
/* #undef HAVE_ZOLTAN2_SCOTCH */

/* define if we have the ParMETIS library*/
/* #undef HAVE_ZOLTAN2_PARMETIS */

/* define if we have the PuLP library*/
/* #undef HAVE_ZOLTAN2_PULP */

/* define if we have the ParMA library*/
/* #undef HAVE_ZOLTAN2_PARMA */

/* define if we have the AMD library*/
/* #undef HAVE_ZOLTAN2_AMD */

/* define if we have the Ovis library*/
/* #undef HAVE_ZOLTAN2_OVIS */

/* define if we have Epetra */
#define HAVE_ZOLTAN2_EPETRA

/* define if we have Galeri */
#define HAVE_ZOLTAN2_GALERI

/* define if we have Pamgen */
#define HAVE_ZOLTAN2_PAMGEN

/* define if we have Anasazi */
/* #undef HAVE_ZOLTAN2_ANASAZI */

/* define to turn on runtime display of
 * total memory committed at points throughout
 * the execution of zoltan2
 */
/* #undef SHOW_ZOLTAN2_LINUX_MEMORY */

/* define to turn on runtime display of
 * maximum memory used by scotch
 * (requires a hack to the scotch library)
 */
/* #undef SHOW_ZOLTAN2_SCOTCH_MEMORY */

/* Use Zoltan's Comm package instead of Tpetra for migration */
/* #undef ZOLTAN2_USEZOLTANCOMM */

==> trilinos-12.12.1-4-x86_64.pkg.tar.xz: usr/include/Zoltan2_config.h <==
/* define if we want to include experimental code */
/* #undef INCLUDE_ZOLTAN2_EXPERIMENTAL */

/* define if we want to include wolf experimental code */
/* #undef INCLUDE_ZOLTAN2_EXPERIMENTAL_WOLF */

/* define if we have MPI */
#define HAVE_ZOLTAN2_MPI

/* define if we want to use OpenMP */
/* #undef HAVE_ZOLTAN2_OMP */

/* define if we have the METIS library*/
/* #undef HAVE_ZOLTAN2_METIS */

/* define if we have the PaToH library*/
/* #undef HAVE_ZOLTAN2_PATOH */

/* define if we have the Scotch library*/
/* #undef HAVE_ZOLTAN2_SCOTCH */

/* define if we have the ParMETIS library*/
/* #undef HAVE_ZOLTAN2_PARMETIS */

/* define if we have the PuLP library*/
/* #undef HAVE_ZOLTAN2_PULP */

/* define if we have the ParMA library*/
/* #undef HAVE_ZOLTAN2_PARMA */

/* define if we have the AMD library*/
/* #undef HAVE_ZOLTAN2_AMD */

/* define if we have the Ovis library*/
/* #undef HAVE_ZOLTAN2_OVIS */

/* define if we have Epetra */
#define HAVE_ZOLTAN2_EPETRA

/* define if we have Galeri */
#define HAVE_ZOLTAN2_GALERI

/* define if we have Pamgen */
#define HAVE_ZOLTAN2_PAMGEN

/* define if we have Anasazi */
/* #undef HAVE_ZOLTAN2_ANASAZI */

/* define to turn on runtime display of
 * total memory committed at points throughout
 * the execution of zoltan2
 */
/* #undef SHOW_ZOLTAN2_LINUX_MEMORY */

/* define to turn on runtime display of
 * maximum memory used by scotch
 * (requires a hack to the scotch library)
 */
/* #undef SHOW_ZOLTAN2_SCOTCH_MEMORY */

/* Use Zoltan's Comm package instead of Tpetra for migration */
/* #undef ZOLTAN2_USEZOLTANCOMM */

/* Enable workarounds for Purify builds */
/* #undef HAVE_ZOLTAN2_PURIFY */

/* define if we have TopoManager installed*/
/* #undef HAVE_ZOLTAN2_TOPOMANAGER */

/* define if we have RCALIB installed*/
/* #undef HAVE_ZOLTAN2_RCALIB */
